@@ -37,7 +37,7 @@ class Command(object):
             self.env = None
 
     def __call(self, args):
-        """simply wraps subprocess.call so we can be verbose"""
+        """wraps subprocess.call so we can be verbose and fix python's SIGPIPE handling"""
         def default_sigpipe():
             "restore default signal handler (http://bugs.python.org/issue1652)"
             signal.signal(signal.SIGPIPE, signal.SIG_DFL)
@@ -54,7 +54,7 @@ class Command(object):
         run self.cmd adding args as additional arguments
 
         be verbose about errors and encode them in the return value, don't pass
-        on exceptons
+        on exceptions
         """
         try:
             retcode = self.__call(args)
@@ -195,6 +195,7 @@ class GitCommand(Command):
     "Mother/Father of all git commands"
     def __init__(self, cmd, args=[], **kwargs):
         Command.__init__(self, 'git', [cmd] + args, **kwargs)
+        self.run_error = "Couldn't run git %s" % cmd
 
 
 class GitInit(GitCommand):
@@ -246,6 +247,15 @@ class GitPull(GitCommand):
         self.run_error = 'Couldn\'t pull "%s" to "%s"' % (branch, repo)
 
 
+class GitFetch(GitCommand):
+    """Wrap git fetch"""
+    def __init__(self, remote = None):
+        opts = []
+        if remote:
+            opts += [remote]
+        GitCommand.__init__(self, 'fetch', opts)
+
+
 class GitMerge(GitCommand):
     """Wrap git merge"""
     def __init__(self, branch, verbose=False):
@@ -278,8 +288,8 @@ class GitTag(GitCommand):
 
 class GitAdd(GitCommand):
     """Wrap git add to add new files"""
-    def __init__(self):
-        GitCommand.__init__(self, 'add')
+    def __init__(self, extra_env=None):
+        GitCommand.__init__(self, 'add', extra_env=extra_env)
         self.run_error = "Couldn't add files"
 
 
