@@ -1,12 +1,15 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006,2007 Guido Guenther <agx@sigxcpu.org>
+# (C) 2006,2007,2010 Guido Guenther <agx@sigxcpu.org>
 """handles command line and config file option parsing for the gbp commands"""
 
 from optparse import OptionParser, OptionGroup
 from ConfigParser import SafeConfigParser
 import os.path
-from gbp.gbp_version import gbp_version
+try:
+    from gbp.gbp_version import gbp_version
+except ImportError:
+    gbp_version = "[Unknown version]"
 
 class GbpOptionParser(OptionParser):
     """
@@ -25,20 +28,23 @@ class GbpOptionParser(OptionParser):
     @cvar config_files: list of config files we parse
     @type config_files: list
     """
-    defaults = { 'builder'         : 'debuild -i\.git/ -I.git',
+    defaults = { 'builder'         : 'debuild -i -I',
                  'cleaner'         : 'debuild -d clean',
                  'debian-branch'   : 'master',
                  'upstream-branch' : 'upstream',
                  'pristine-tar'    : 'False',
                  'filter-pristine-tar' : 'False',
                  'sign-tags'       : 'False',
+                 'force-create'    : 'False',
                  'no-create-orig'  : 'False',
                  'keyid'           : '',
                  'posttag'         : '',
                  'postbuild'       : '',
+                 'prebuild'        : '',
                  'postimport'      : '',
                  'debian-tag'      : 'debian/%(version)s',
                  'upstream-tag'    : 'upstream/%(version)s',
+                 'import-msg'      : 'Imported Upstream version %(version)s',
                  'filter'          : [],
                  'snapshot-number' : 'snapshot + 1',
                  'git-log'         : '--no-merges',
@@ -47,11 +53,20 @@ class GbpOptionParser(OptionParser):
                  'overlay'         : 'False',
                  'tarball-dir'     : '',
                  'ignore-new'      : 'False',
+                 'ignore-branch'   : 'False',
                  'meta'            : 'False',
                  'meta-closes'     : 'Closes|LP',
                  'full'            : 'False',
                  'id-length'       : '0',
                  'git-author'      : 'False',
+                 'ignore-regex'    : '',
+                 'compression'     : 'auto',
+                 'compression-level': '9',
+                 'remote-url-pattern' : 'ssh://alioth.debian.org/git/collab-maint/%(pkg)s.git',
+                 'multimaint-merge' : 'False',
+                 'pbuilder'        : 'False',
+                 'dist'            : 'sid',
+                 'arch'            : '',
              }
     help = {
              'debian-branch':
@@ -66,6 +81,8 @@ class GbpOptionParser(OptionParser):
                   "sign tags, default is '%(sign-tags)s'",
              'keyid':
                   "GPG keyid to sign tags with, default is '%(keyid)s'",
+             'import-msg':
+                  "format string for commit message, default is '%(import-msg)s'",
              'pristine-tar':
                   "use pristine-tar to create .orig.tar.gz, default is '%(pristine-tar)s'",
              'filter-pristine-tar':
@@ -80,8 +97,20 @@ class GbpOptionParser(OptionParser):
                   "parse meta tags in commit messages, default is '%(meta)s'",
              'ignore-new':
                   "build with uncommited changes in the source tree, default is '%(ignore-new)s'",
+             'ignore-branch':
+                  "build although debian-branch != current branch, default is '%(ignore-new)s'",
              'overlay':
                   "extract orig tarball when using export-dir option, default is '%(overlay)s'",
+             'remote-url-pattern':
+                  "Remote url pattern to create the repo at, default is '%(remote-url-pattern)s'",
+             'multimaint-merge':
+                  "Merge commits by maintainer, default is '%(multimaint-merge)s'",
+             'pbuilder':
+                  "Invoke git-pbuilder for building, default is '%(pbuilder)s'",
+             'dist':
+                  "Build for this distribution when using git-pbuilder, default is '%(dist)s'",
+             'arch':
+                  "Build for this architecture when using git-pbuilder, default is '%(arch)s'",
            }
     config_files = [ '/etc/git-buildpackage/gbp.conf',
                      os.path.expanduser('~/.gbp.conf'),
